.. _phononic-band_gaps_conf:

phononic/band_gaps_conf.py
==========================

**Description**


Configuration classes for acoustic band gaps in a strongly heterogeneous
elastic body.




:download:`source code </../sfepy/examples/phononic/band_gaps_conf.py>`

.. literalinclude:: /../sfepy/examples/phononic/band_gaps_conf.py

